@@ -1,10 +1,10 @@
 import abc
-from typing import List
+from typing import Sequence
 
 from ._stats import PingStats
 
 
 class PingParserInterface(metaclass=abc.ABCMeta):
     @abc.abstractmethod
-    def parse(self, ping_message: List[str]) -> PingStats:  # pragma: no cover
+    def parse(self, ping_message: Sequence[str]) -> PingStats:  # pragma: no cover
         pass
