@@ -4,7 +4,7 @@
 
 import abc
 import re
-from datetime import datetime  # noqa
+from datetime import datetime, tzinfo
 from typing import Dict, List, Optional, Pattern, Sequence, Tuple, Union  # noqa
 
 import pyparsing as pp
@@ -20,6 +20,8 @@ from .error import ParseError, ParseErrorReason
 
 
 class IcmpReplyKey:
+    DESTINATION = "destination"
+    BYTES = "bytes"
     TIMESTAMP = "timestamp"
     TIMESTAMP_NO_ANS = "timestamp_no_ans"
     SEQUENCE_NO = "icmp_seq"
@@ -30,10 +32,17 @@ class IcmpReplyKey:
 
 class PingParser(PingParserInterface):
 
+    _BYTES_PATTERN = r"\s*(?P<{key}>[0-9]+) bytes".format(key=IcmpReplyKey.BYTES)
+    _DEST_PATTERN = r"(?P<{key}>[a-zA-Z0-9:\-\.\(\)% ]+)".format(
+        key=IcmpReplyKey.DESTINATION
+    )  # host or ipv4/ipv6 addr
     _IPADDR_PATTERN = r"(\d{1,3}\.){3}\d{1,3}"
-    _ICMP_SEQ_PATTERN = r"icmp_seq=(?P<icmp_seq>\d+)"
-    _TTL_PATTERN = r"ttl=(?P<ttl>\d+)"
-    _TIME_PATTERN = r"time=(?P<time>[0-9\.]+)"
+    _ICMP_SEQ_PATTERN = r"\s*icmp_seq=(?P<{key}>\d+)".format(key=IcmpReplyKey.SEQUENCE_NO)
+    _TTL_PATTERN = r"\s*ttl=(?P<{key}>\d+)".format(key=IcmpReplyKey.TTL)
+    _TIME_PATTERN = r"\s*time[=<](?P<{key}>[0-9\.]+)".format(key=IcmpReplyKey.TIME)
+
+    def __init__(self, timezone: Optional[tzinfo] = None) -> None:
+        self.__timezone = timezone
 
     @abc.abstractproperty
     def _parser_name(self) -> str:  # pragma: no cover
@@ -73,7 +82,13 @@ class PingParser(PingParserInterface):
                 continue
 
             results = match.groupdict()
-            reply = {}  # type: Dict[str, Union[bool, float, int, datetime]]
+            reply = {}  # type: Dict[str, Union[str, bool, float, int, datetime]]
+
+            if IcmpReplyKey.DESTINATION in results:
+                reply[IcmpReplyKey.DESTINATION] = results[IcmpReplyKey.DESTINATION]
+
+            if IcmpReplyKey.BYTES in results:
+                reply[IcmpReplyKey.BYTES] = int(results[IcmpReplyKey.BYTES])
 
             if results.get(IcmpReplyKey.TIMESTAMP):
                 reply[IcmpReplyKey.TIMESTAMP] = self.__timestamp_to_datetime(
@@ -84,13 +99,13 @@ class PingParser(PingParserInterface):
                     results[IcmpReplyKey.TIMESTAMP_NO_ANS]
                 )
 
-            if results.get(IcmpReplyKey.SEQUENCE_NO):
+            if IcmpReplyKey.SEQUENCE_NO in results:
                 reply[IcmpReplyKey.SEQUENCE_NO] = int(results[IcmpReplyKey.SEQUENCE_NO])
 
-            if results.get(IcmpReplyKey.TTL):
+            if IcmpReplyKey.TTL in results:
                 reply[IcmpReplyKey.TTL] = int(results[IcmpReplyKey.TTL])
 
-            if results.get(IcmpReplyKey.TIME):
+            if IcmpReplyKey.TIME in results:
                 reply[IcmpReplyKey.TIME] = float(results[IcmpReplyKey.TIME])
 
             if duplicate_packet_regexp.search(line):
@@ -116,7 +131,11 @@ class PingParser(PingParserInterface):
         return (lines[stats_headline_idx], packet_info_line, body_line_list)
 
     def _parse_destination(self, stats_headline: str) -> str:
-        return stats_headline.lstrip("--- ").rstrip(" ping statistics ---")
+        match = re.search(self._stats_headline_pattern, stats_headline)
+        if not match:
+            return "unknown"
+
+        return match.groupdict()[IcmpReplyKey.DESTINATION].strip(":")
 
     def __find_stats_headline_idx(self, lines: Sequence[str], re_stats_header: Pattern) -> int:
         for i, line in enumerate(lines):
@@ -128,7 +147,7 @@ class PingParser(PingParserInterface):
         return i
 
     def __timestamp_to_datetime(self, timestamp: str) -> datetime:
-        return DateTime(timestamp.lstrip("[").rstrip("]")).force_convert()
+        return DateTime(timestamp.lstrip("[").rstrip("]"), timezone=self.__timezone).force_convert()
 
     def __validate_stats_body(self, body_line_list: Sequence[str]) -> None:
         if typepy.is_empty_sequence(body_line_list):
@@ -169,7 +188,7 @@ class NullPingParser(PingParser):
     def _is_support_packet_duplicate(self) -> bool:  # pragma: no cover
         return False
 
-    def parse(self, ping_message: List[str]) -> PingStats:  # pragma: no cover
+    def parse(self, ping_message: Sequence[str]) -> PingStats:  # pragma: no cover
         return PingStats()
 
     def _preprocess_parse_stats(
@@ -183,8 +202,8 @@ class LinuxPingParser(PingParser):
     def _parser_name(self) -> str:
         return "Linux"
 
-    _TIMESTAMP_PATTERN = r"(?P<timestamp>\[[0-9\.]+\])"
-    _NO_ANS_TIMESTAMP_PATTERN = r"(?P<timestamp_no_ans>\[[0-9\.]+\])"
+    _TIMESTAMP_PATTERN = r"(?P<{key}>\[[0-9\.]+\])".format(key=IcmpReplyKey.TIMESTAMP)
+    _NO_ANS_TIMESTAMP_PATTERN = r"(?P<{key}>\[[0-9\.]+\])".format(key=IcmpReplyKey.TIMESTAMP_NO_ANS)
 
     @property
     def _icmp_no_ans_pattern(self) -> str:
@@ -194,23 +213,25 @@ class LinuxPingParser(PingParser):
     def _icmp_reply_pattern(self) -> str:
         return (
             self._TIMESTAMP_PATTERN
-            + r"?\s?.+ from .+?: "
+            + "?"
+            + self._BYTES_PATTERN
+            + r"\s+from "
+            + self._DEST_PATTERN
+            + ":"
             + self._ICMP_SEQ_PATTERN
-            + " "
             + self._TTL_PATTERN
-            + " "
             + self._TIME_PATTERN
         )
 
     @property
     def _stats_headline_pattern(self) -> str:
-        return "--- .* ping statistics ---"
+        return r"--- {} ping statistics ---".format(self._DEST_PATTERN)
 
     @property
     def _is_support_packet_duplicate(self) -> bool:
         return True
 
-    def parse(self, ping_message: List[str]) -> PingStats:
+    def parse(self, ping_message: Sequence[str]) -> PingStats:
         icmp_replies = self._parse_icmp_reply(ping_message)
         stats_headline, packet_info_line, body_line_list = self._preprocess_parse_stats(
             lines=ping_message
@@ -277,17 +298,24 @@ class WindowsPingParser(PingParser):
 
     @property
     def _icmp_reply_pattern(self) -> str:
-        return " from  .+?: " + self._TTL_PATTERN + " " + self._TIME_PATTERN
+        return (
+            " from "
+            + self._DEST_PATTERN
+            + r":\s*bytes=(?P<{key}>[0-9]+)".format(key=IcmpReplyKey.BYTES)
+            + self._TIME_PATTERN
+            + "ms"
+            + self._TTL_PATTERN
+        )
 
     @property
     def _stats_headline_pattern(self) -> str:
-        return "^Ping statistics for "
+        return r"^Ping statistics for {}".format(self._DEST_PATTERN)
 
     @property
     def _is_support_packet_duplicate(self) -> bool:
         return False
 
-    def parse(self, ping_message: List[str]) -> PingStats:
+    def parse(self, ping_message: Sequence[str]) -> PingStats:
         icmp_replies = self._parse_icmp_reply(ping_message)
         stats_headline, packet_info_line, body_line_list = self._preprocess_parse_stats(
             lines=ping_message
@@ -342,9 +370,6 @@ class WindowsPingParser(PingParser):
             icmp_replies=icmp_replies,
         )
 
-    def _parse_destination(self, stats_headline):
-        return stats_headline.lstrip("Ping statistics for ").rstrip(":")
-
 
 class MacOsPingParser(PingParser):
     @property
@@ -354,23 +379,24 @@ class MacOsPingParser(PingParser):
     @property
     def _icmp_reply_pattern(self) -> str:
         return (
-            " from .+?: "
+            self._BYTES_PATTERN
+            + r"\s+from "
+            + self._DEST_PATTERN
+            + ":"
             + self._ICMP_SEQ_PATTERN
-            + " "
             + self._TTL_PATTERN
-            + " "
             + self._TIME_PATTERN
         )
 
     @property
     def _stats_headline_pattern(self) -> str:
-        return "--- .* ping statistics ---"
+        return r"--- {} ping statistics ---".format(self._DEST_PATTERN)
 
     @property
     def _is_support_packet_duplicate(self) -> bool:
         return True
 
-    def parse(self, ping_message: List[str]) -> PingStats:
+    def parse(self, ping_message: Sequence[str]) -> PingStats:
         icmp_replies = self._parse_icmp_reply(ping_message)
         stats_headline, packet_info_line, body_line_list = self._preprocess_parse_stats(
             lines=ping_message
@@ -438,14 +464,20 @@ class AlpineLinuxPingParser(LinuxPingParser):
     @property
     def _icmp_reply_pattern(self) -> str:
         return (
-            " from .+?: " + r"seq=(?P<icmp_seq>\d+) " + self._TTL_PATTERN + " " + self._TIME_PATTERN
+            self._BYTES_PATTERN
+            + r"\s+from "
+            + self._DEST_PATTERN
+            + ": "
+            + r"seq=(?P<{key}>\d+) ".format(key=IcmpReplyKey.SEQUENCE_NO)
+            + self._TTL_PATTERN
+            + self._TIME_PATTERN
         )
 
     @property
     def _is_support_packet_duplicate(self) -> bool:
         return True
 
-    def parse(self, ping_message: List[str]) -> PingStats:
+    def parse(self, ping_message: Sequence[str]) -> PingStats:
         icmp_replies = self._parse_icmp_reply(ping_message)
         stats_headline, packet_info_line, body_line_list = self._preprocess_parse_stats(
             lines=ping_message
