@@ -5,4 +5,5 @@ import humanreadable as hr
 
 
 TimeArg = Union[hr.Time, int, str, None]
-IcmpReplies = Sequence[Dict[str, Union[bool, float, int, datetime]]]
+IcmpReplies = Sequence[Dict[str, Union[str, bool, float, int, datetime]]]
+PingAddOpts = Union[str, Sequence[str]]
