@@ -6,6 +6,7 @@ from datetime import datetime
 from textwrap import dedent
 
 import pytest
+import pytz
 
 from pingparsing import ParseError, PingResult
 
@@ -97,26 +98,48 @@ UBUNTU_FAIL_0 = PingTestData(
         "packet_duplicate_rate": 0.0,
     },
     [
-        {"timestamp": datetime(2020, 8, 8, 10, 5, 33, 81556), "icmp_seq": 1, "duplicate": False,},
         {
-            "timestamp": datetime(2020, 8, 8, 10, 5, 33, 81898),
+            "timestamp": datetime(2020, 8, 8, 10, 5, 33, 81556, tzinfo=pytz.UTC),
+            "icmp_seq": 1,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.11.222",
+            "timestamp": datetime(2020, 8, 8, 10, 5, 33, 81898, tzinfo=pytz.UTC),
             "icmp_seq": 2,
             "ttl": 64,
             "time": 0.262,
             "duplicate": False,
         },
-        {"timestamp": datetime(2020, 8, 8, 10, 5, 35, 129517), "icmp_seq": 3, "duplicate": False,},
-        {"timestamp": datetime(2020, 8, 8, 10, 5, 36, 153055), "icmp_seq": 4, "duplicate": False,},
-        {"timestamp": datetime(2020, 8, 8, 10, 5, 37, 180056), "icmp_seq": 5, "duplicate": False,},
         {
-            "timestamp": datetime(2020, 8, 8, 10, 5, 37, 180326),
+            "timestamp": datetime(2020, 8, 8, 10, 5, 35, 129517, tzinfo=pytz.UTC),
+            "icmp_seq": 3,
+            "duplicate": False,
+        },
+        {
+            "timestamp": datetime(2020, 8, 8, 10, 5, 36, 153055, tzinfo=pytz.UTC),
+            "icmp_seq": 4,
+            "duplicate": False,
+        },
+        {
+            "timestamp": datetime(2020, 8, 8, 10, 5, 37, 180056, tzinfo=pytz.UTC),
+            "icmp_seq": 5,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.11.222",
+            "timestamp": datetime(2020, 8, 8, 10, 5, 37, 180326, tzinfo=pytz.UTC),
             "icmp_seq": 6,
             "ttl": 64,
             "time": 0.221,
             "duplicate": False,
         },
         {
-            "timestamp": datetime(2020, 8, 8, 10, 5, 38, 201538),
+            "bytes": 64,
+            "destination": "192.168.11.222",
+            "timestamp": datetime(2020, 8, 8, 10, 5, 38, 201538, tzinfo=pytz.UTC),
             "icmp_seq": 7,
             "ttl": 64,
             "time": 0.257,
@@ -209,11 +232,46 @@ MACOS_SUCCESS_0 = PingTestData(
         "rtt_mdev": 8.292,
     },
     [
-        {"icmp_seq": 0, "ttl": 53, "time": 20.482, "duplicate": False},
-        {"icmp_seq": 1, "ttl": 53, "time": 32.55, "duplicate": False},
-        {"icmp_seq": 2, "ttl": 53, "time": 32.013, "duplicate": False},
-        {"icmp_seq": 3, "ttl": 53, "time": 28.498, "duplicate": False},
-        {"icmp_seq": 4, "ttl": 53, "time": 46.093, "duplicate": False},
+        {
+            "bytes": 64,
+            "destination": "172.217.6.238",
+            "icmp_seq": 0,
+            "ttl": 53,
+            "time": 20.482,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "172.217.6.238",
+            "icmp_seq": 1,
+            "ttl": 53,
+            "time": 32.55,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "172.217.6.238",
+            "icmp_seq": 2,
+            "ttl": 53,
+            "time": 32.013,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "172.217.6.238",
+            "icmp_seq": 3,
+            "ttl": 53,
+            "time": 28.498,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "172.217.6.238",
+            "icmp_seq": 4,
+            "ttl": 53,
+            "time": 46.093,
+            "duplicate": False,
+        },
     ],
 )
 MACOS_SUCCESS_1 = PingTestData(
@@ -289,6 +347,30 @@ MACOS_UNREACHABLE_1 = PingTestData(
     },
     [],
 )
+MACOS_UNREACHABLE_2 = PingTestData(
+    dedent(
+        """\
+        PING example.net (93.184.216.34): 56 data bytes
+
+        --- example.net ping statistics ---
+        10 packets transmitted, 0 packets received, 100.0% packet loss
+        """
+    ),
+    {
+        "destination": "example.net",
+        "packet_transmit": 10,
+        "packet_receive": 0,
+        "packet_loss_count": 10,
+        "packet_loss_rate": 100.0,
+        "packet_duplicate_count": 0,
+        "packet_duplicate_rate": None,
+        "rtt_min": None,
+        "rtt_avg": None,
+        "rtt_max": None,
+        "rtt_mdev": None,
+    },
+    [],
+)
 MACOS_DUPLICATE_0 = PingTestData(
     dedent(
         """\
@@ -376,17 +458,130 @@ ALPINE_LINUX_DUP_LOSS = PingTestData(
         "rtt_mdev": None,
     },
     [
-        {"icmp_seq": 0, "ttl": 64, "time": 0.936, "duplicate": False},
-        {"icmp_seq": 0, "ttl": 64, "time": 1.003, "duplicate": True},
-        {"icmp_seq": 1, "ttl": 64, "time": 0.802, "duplicate": False},
-        {"icmp_seq": 2, "ttl": 64, "time": 0.696, "duplicate": False},
-        {"icmp_seq": 3, "ttl": 64, "time": 0.664, "duplicate": False},
-        {"icmp_seq": 4, "ttl": 64, "time": 1.194, "duplicate": False},
-        {"icmp_seq": 5, "ttl": 64, "time": 0.613, "duplicate": False},
-        {"icmp_seq": 6, "ttl": 64, "time": 0.898, "duplicate": False},
-        {"icmp_seq": 8, "ttl": 64, "time": 1.066, "duplicate": False},
-        {"icmp_seq": 9, "ttl": 64, "time": 1.144, "duplicate": False},
-        {"icmp_seq": 9, "ttl": 64, "time": 1.219, "duplicate": True},
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 0,
+            "ttl": 64,
+            "time": 0.936,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 0,
+            "ttl": 64,
+            "time": 1.003,
+            "duplicate": True,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 1,
+            "ttl": 64,
+            "time": 0.802,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 2,
+            "ttl": 64,
+            "time": 0.696,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 3,
+            "ttl": 64,
+            "time": 0.664,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 4,
+            "ttl": 64,
+            "time": 1.194,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 5,
+            "ttl": 64,
+            "time": 0.613,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 6,
+            "ttl": 64,
+            "time": 0.898,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 8,
+            "ttl": 64,
+            "time": 1.066,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 9,
+            "ttl": 64,
+            "time": 1.144,
+            "duplicate": False,
+        },
+        {
+            "bytes": 64,
+            "destination": "192.168.2.106",
+            "icmp_seq": 9,
+            "ttl": 64,
+            "time": 1.219,
+            "duplicate": True,
+        },
+    ],
+)
+
+IPV6_LINUX = PingTestData(
+    dedent(
+        r"""\
+        PING ff02::2%usb0(ff02::2%usb0) 56 data bytes
+        64 bytes from fe80::783c:caff:fe12:b46c%usb0: icmp_seq=1 ttl=64 time=2.71 ms
+
+        --- ff02::2%usb0 ping statistics ---
+        1 packets transmitted, 1 received, 0% packet loss, time 0ms
+        rtt min/avg/max/mdev = 2.708/2.708/2.708/0.000 ms
+        """
+    ),
+    {
+        "destination": r"ff02::2%usb0",
+        "packet_transmit": 1,
+        "packet_receive": 1,
+        "packet_duplicate_count": 0,
+        "packet_duplicate_rate": 0,
+        "packet_loss_count": 0,
+        "packet_loss_rate": 0.0,
+        "rtt_min": 2.708,
+        "rtt_avg": 2.708,
+        "rtt_max": 2.708,
+        "rtt_mdev": 0.0,
+    },
+    [
+        {
+            "bytes": 64,
+            "destination": r"fe80::783c:caff:fe12:b46c%usb0",
+            "icmp_seq": 1,
+            "ttl": 64,
+            "time": 2.71,
+            "duplicate": False,
+        },
     ],
 )
 
@@ -424,7 +619,17 @@ WINDOWS10_LOSS = PingTestData(
         "rtt_max": 33.0,
         "rtt_mdev": None,
     },
-    [],
+    [
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 16.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 6.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 12.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 16.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 8.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 33.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 13.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 23.0, "duplicate": False},
+        {"bytes": 32, "destination": "192.168.2.106", "ttl": 64, "time": 1.0, "duplicate": False},
+    ],
 )
 WINDOWS_UNREACHABLE_0 = PingTestData(
     dedent(
@@ -478,6 +683,7 @@ class Test_PingParsing_parse:
             [MACOS_SUCCESS_1, "macOS"],
             [MACOS_UNREACHABLE_0, "macOS"],
             [MACOS_UNREACHABLE_1, "macOS"],
+            [MACOS_UNREACHABLE_2, "macOS"],
             [MACOS_DUPLICATE_0, "macOS"],
             [ALPINE_LINUX_SUCCESS, "AlpineLinux"],
             [ALPINE_LINUX_DUP_LOSS, "AlpineLinux"],
@@ -486,6 +692,7 @@ class Test_PingParsing_parse:
             [WINDOWS_UNREACHABLE_0, "Windows"],
             [WINDOWS_UNREACHABLE_1, "Windows"],
             [WINDOWS_UNREACHABLE_2, "Windows"],
+            [IPV6_LINUX, "Linux"],
         ],
     )
     def test_normal_text(self, ping_parser, test_data, parser_name):
